# Python extended Nextcloud Client

This library is available through `pip` as [pyncclient-ext](https://pypi.org/project/pyncclient-ext/) .
It is a subclass of [pyncclient](https://pypi.org/project/pyncclient/) library,
implementing chunked upload from a stream and partial system tag management and assignment.